MedianTimePast

Struct MedianTimePast 

pub struct MedianTimePast(/* private fields */);
The median timestamp of 11 consecutive blocks, representing “the timestamp” of the final block for locktime-checking purposes.

Time-based locktimes are not measured against the timestamps in individual block headers, since these are not monotone and may be subject to miner manipulation. Instead, locktimes use the “median-time-past” (MTP) of the most recent 11 blocks, a quantity which is required by consensus to be monotone and which is difficult for any individual miner to manipulate.

Implementations

Source

impl MedianTimePast

pub const MIN: MedianTimePast

The minimum MTP allowable in a locktime (Tue Nov 05 1985 00:53:20 GMT+0000).

pub const MAX: MedianTimePast

The maximum MTP allowable in a locktime (Sun Feb 07 2106 06:28:15 GMT+0000).

pub fn new( timestamps: [BlockTime; 11], ) -> Result<MedianTimePast, ConversionError>

Constructs an MedianTimePast by computing the median-time-past from the last 11 block timestamps.

Because block timestamps are not monotonic, this function internally sorts them; it is therefore not important what order they appear in the array; use whatever is most convenient.

Errors

If the median block timestamp is not in the allowable range of MTPs in a locktime: [500_000_000, 2^32 - 1]. Because there is a consensus rule that MTP be monotonically increasing, and the MTP of the first 11 blocks exceeds 500_000_000 for every real-life chain, this error typically cannot be hit in practice.

pub fn from_hex(s: &str) -> Result<MedianTimePast, ParseTimeError>

Constructs a new MedianTimePast from a big-endian hex-encoded u32.

The input string may or may not contain a typical hex prefix e.g., 0x.

Errors

If the input string is not a valid hex representation of a block time.

pub const fn from_u32(n: u32) -> Result<MedianTimePast, ConversionError>

Constructs a new MTP directly from a u32 value.

This function, with MedianTimePast::to_u32, is used to obtain a raw MTP value. It is not used to convert to or from a block timestamp, which is not a MTP.

Errors

If n is not in the allowable range of MTPs in a locktime: [500_000_000, 2^32 - 1].

Examples
use bitcoin_units::locktime::absolute;

let t: u32 = 1653195600; // May 22nd, 5am UTC.
let time = absolute::MedianTimePast::from_u32(t)?;
assert_eq!(time.to_u32(), t);
pub const fn to_u32(self) -> u32

Converts this MedianTimePast to a raw u32 value.

Examples
use bitcoin_units::locktime::absolute;

assert_eq!(absolute::MedianTimePast::MIN.to_u32(), 500_000_000);
pub fn is_satisfied_by(self, time: MedianTimePast) -> bool

Returns true if a transaction with this locktime can be included in the next block.

self is the value of the LockTime and if time is the median time past of the block at the chain tip then a transaction with this lock can be broadcast for inclusion in the next block.