Module error

Module error 

Error types for bitcoin amounts.

Structs

AmountDecoderError
An error consensus decoding an Amount.
BadPositionError
Error returned when a valid character (e.g. ‘_’) is in an invalid/bad position.
InputTooLargeError
Error returned when the input string is too large.
InvalidCharacterError
Error returned when the input contains an invalid character.
MissingDenominationError
Error returned when the denomination is empty.
MissingDigitsError
Error returned when digits were expected in the input but there were none.
OutOfRangeError
Error returned when a parsed amount is too big or too small.
ParseAmountError
Error returned when parsing an amount fails.
ParseError
Error returned when parsing an amount with denomination fails.
PossiblyConfusingDenominationError
Error returned when parsing a possibly confusing denomination.
TooPreciseError
Error returned when the input string has higher precision than satoshis.
UnknownDenominationError
Error returned when parsing an unknown denomination.

Enums

ParseDenominationError
An error during amount parsing.