#[non_exhaustive]pub enum InvalidBlockError {
InvalidMerkleRoot,
InvalidWitnessCommitment,
NoTransactions,
InvalidCoinbase,
}Expand description
Invalid block error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidMerkleRoot
Header Merkle root does not match the calculated Merkle root.
InvalidWitnessCommitment
The witness commitment in coinbase transaction does not match the calculated witness_root.
NoTransactions
Block has no transactions (missing coinbase).
InvalidCoinbase
The first transaction is not a valid coinbase transaction.