int_from_string

Function int_from_string 

pub fn int_from_string<T>(s: String) -> Result<T, ParseIntError>
where T: Integer,
Parses the input string as an integer returning an error carrying rich context.

Errors

On error the input string is moved into the error return without allocating.