Module error

Module error 

Error types for the relative locktime module.

Structs

DisabledLockTimeError
Error returned when a sequence number is parsed as a lock time, but its “disable” flag is set.
InvalidHeightError
Error returned when NumberOfBlocks::is_satisfied_by is incorrectly called.
InvalidTimeError
Error returned when NumberOf512Seconds::is_satisfied_by is incorrectly called.
TimeOverflowError
Error returned when the input time in seconds was too large to be encoded to a 16 bit 512 second interval.

Enums

IsSatisfiedByError
Error returned when attempting to satisfy lock fails.
IsSatisfiedByHeightError
Error returned when is_satisfied_by_height fails.
IsSatisfiedByTimeError
Error returned when is_satisfied_by_time fails.