pub struct PushBytes(/* private fields */);Expand description
Byte slices that can be in Bitcoin script.
The encoding of Bitcoin script restricts data pushes to be less than 2^32 bytes long. This type represents slices that are guaranteed to be within the limit so they can be put in the script safely.
Implementations