Block

Struct Block 

pub struct Block<V = Unchecked>
where V: Validation,
{ /* private fields */ }
Bitcoin block.

A collection of transactions with an attached proof of work.

See Bitcoin Wiki: Block for more information.

Bitcoin Core References

Implementations

Source

impl Block<Unchecked>

pub fn new_unchecked(header: Header, transactions: Vec<Transaction>) -> Self

Constructs a new Block without doing any validation.

pub fn assume_checked( self, witness_root: Option<WitnessMerkleNode>, ) -> Block<Checked>

Ignores block validation logic and just assumes you know what you are doing.

You should only use this function if you trust the block i.e., it comes from a trusted node.

pub fn into_parts(self) -> (Header, Vec<Transaction>)

Decomposes block into its constituent parts.

pub fn as_parts(&self) -> (&Header, &[Transaction])

Returns the constituent parts of the block by reference.

pub fn validate(self) -> Result<Block<Checked>, InvalidBlockError>

Validates (or checks) a block.

We define valid as:

  • The Merkle root of the header matches Merkle root of the transaction list.
  • The witness commitment in coinbase matches the transaction list.
Errors

Returns an error if:

  • The block has no transactions.
  • The first transaction is not a coinbase transaction.
  • The Merkle root of the header does not match the Merkle root of the transaction list.
  • The witness commitment in the coinbase does not match the transaction list.
pub fn check_merkle_root(&self) -> bool

Checks if Merkle root of header matches Merkle root of the transaction list.

pub fn compute_witness_commitment( &self, witness_reserved_value: &[u8], ) -> Option<(WitnessMerkleNode, WitnessCommitment)>

Computes the witness commitment for a list of transactions.

pub fn check_witness_commitment(&self) -> (bool, Option<WitnessMerkleNode>)

Checks if witness commitment in coinbase matches the transaction list.

Source

impl Block<Checked>

pub fn header(&self) -> &Header

Gets a reference to the block header.

pub fn transactions(&self) -> &[Transaction]

Gets a reference to the block’s list of transactions.

pub fn cached_witness_root(&self) -> Option<WitnessMerkleNode>

Returns the cached witness root if one is present.

It is assumed that a block will have the witness root calculated and cached as part of the validation process.

Source

impl<V: Validation> Block<V>

pub fn block_hash(&self) -> BlockHash

Returns the block hash.