pub struct BlockHash(/* private fields */);Expand description
A bitcoin block hash.
Implementations
Sourceimpl BlockHash
impl BlockHash
Sourcepub const GENESIS_PREVIOUS_BLOCK_HASH: Self
pub const GENESIS_PREVIOUS_BLOCK_HASH: Self
Dummy hash used as the previous blockhash of the genesis block.
impl BlockHash
impl BlockHash
pub const fn from_byte_array(bytes: [u8; 32]) -> Self
pub const fn from_byte_array(bytes: [u8; 32]) -> Self
Constructs a new type from the underlying byte array.
pub const fn to_byte_array(self) -> [u8; 32]
pub const fn to_byte_array(self) -> [u8; 32]
Returns the underlying byte array.
pub const fn as_byte_array(&self) -> &[u8; 32]
pub const fn as_byte_array(&self) -> &[u8; 32]
Returns a reference to the underlying byte array.