TxMerkleNode

Struct TxMerkleNode 

pub struct TxMerkleNode(/* private fields */);
A hash of the Merkle tree branch or root for transactions.

Implementations



impl TxMerkleNode

pub const fn from_byte_array(bytes: [u8; 32]) -> Self

Constructs a new type from the underlying byte array.

pub const fn to_byte_array(self) -> [u8; 32]

Returns the underlying byte array.

pub const fn as_byte_array(&self) -> &[u8; 32]

Returns a reference to the underlying byte array.

Source

impl TxMerkleNode

pub fn from_leaf(leaf: Txid) -> Self

Convert a Txid hash to a leaf node of the tree.

pub fn combine(&self, other: &Self) -> Self

Combine two nodes to get a single node. The final node of a tree is called the “root”.

pub fn calculate_root<I: Iterator<Item = Txid>>(iter: I) -> Option<Self>

Given an iterator of leaves, compute the Merkle root.

Returns None if the iterator was empty, or if the transaction list contains consecutive duplicates which would trigger CVE 2012-2459. Blocks with duplicate transactions will always be invalid, so there is no harm in us refusing to compute their merkle roots.

Unless you are certain your transaction list is nonempty and has no duplicates, you should not unwrap the Option returned by this method!