pub struct Txid(/* private fields */);Expand description
A bitcoin transaction hash/transaction ID.
For compatibility with the existing Bitcoin infrastructure and historical and current
versions of the Bitcoin Core software itself, this and other sha256d::Hash types, are
serialized in reverse byte order when converted to a hex string via std::fmt::Display
trait operations.
Implementations
Sourceimpl Txid
impl Txid
Sourcepub const COINBASE_PREVOUT: Self
pub const COINBASE_PREVOUT: Self
The Txid used in a coinbase prevout.
This is used as the “txid” of the dummy input of a coinbase transaction. This is not a real
TXID and should not be used in any other contexts. See OutPoint::COINBASE_PREVOUT.
impl Txid
impl Txid
pub const fn from_byte_array(bytes: [u8; 32]) -> Self
pub const fn from_byte_array(bytes: [u8; 32]) -> Self
Constructs a new type from the underlying byte array.
pub const fn to_byte_array(self) -> [u8; 32]
pub const fn to_byte_array(self) -> [u8; 32]
Returns the underlying byte array.
pub const fn as_byte_array(&self) -> &[u8; 32]
pub const fn as_byte_array(&self) -> &[u8; 32]
Returns a reference to the underlying byte array.