Witness

Struct Witness 

pub struct Witness { /* private fields */ }
The Witness is the data used to unlock bitcoin since the SegWit upgrade.

Can be logically seen as an array of bytestrings, i.e. Vec<Vec<u8>>, and it is serialized on the wire in that format. You can convert between this type and Vec<Vec<u8>> by using Witness::from_slice and Witness::to_vec.

For serialization and deserialization performance it is stored internally as a single Vec, saving some allocations.

Implementations

Source

impl Witness

pub const fn new() -> Self

Constructs a new empty Witness.

pub fn from_slice<T: AsRef<[u8]>>(slice: &[T]) -> Self

Constructs a new Witness object from a slice of bytes slices where each slice is a witness item.

pub fn to_vec(&self) -> Vec<Vec<u8>>

Convenience method to create an array of byte-arrays from this witness.

pub fn is_empty(&self) -> bool

Returns true if the witness contains no element.

pub fn iter(&self) -> Iter<'_>

Returns a struct implementing Iterator.

pub const fn len(&self) -> usize

Returns the number of elements this witness holds.

pub fn size(&self) -> usize

Returns the number of bytes this witness contributes to a transactions total size.

Panics

If the size calculation overflows.

pub fn clear(&mut self)

Clears the witness.

pub fn push<T: AsRef<[u8]>>(&mut self, new_element: T)

Pushes a new element on the witness, requires an allocation.

pub fn last(&self) -> Option<&[u8]>

Returns the last element in the witness, if any.

pub fn get_back(&self, index: usize) -> Option<&[u8]>

Retrieves an element from the end of the witness by its reverse index.

index is 0-based from the end, where 0 is the last element, 1 is the second-to-last, etc.

Returns None if the requested index is beyond the witness’s elements.

Examples
use bitcoin_primitives::witness::Witness;

let mut witness = Witness::new();
witness.push(b"A");
witness.push(b"B");
witness.push(b"C");
witness.push(b"D");

assert_eq!(witness.get_back(0), Some(b"D".as_slice()));
assert_eq!(witness.get_back(1), Some(b"C".as_slice()));
assert_eq!(witness.get_back(2), Some(b"B".as_slice()));
assert_eq!(witness.get_back(3), Some(b"A".as_slice()));
assert_eq!(witness.get_back(4), None);
pub fn get(&self, index: usize) -> Option<&[u8]>

Returns a specific element from the witness by its index, if any.

pub fn from_hex<I, T>(iter: I) -> Result<Self, DecodeVariableLengthBytesError>
where I: IntoIterator<Item = T>, T: AsRef<str>,

Constructs a new witness from a list of hex strings.

Errors

This function will return an error if any of the hex strings are invalid.