pub struct WitnessCommitment(/* private fields */);Expand description
A hash corresponding to the witness structure commitment in the coinbase transaction.
Implementations
Sourceimpl WitnessCommitment
impl WitnessCommitment
Sourcepub const GENESIS_PREVIOUS_BLOCK_HASH: Self
pub const GENESIS_PREVIOUS_BLOCK_HASH: Self
Dummy hash used as the previous blockhash of the genesis block.
impl WitnessCommitment
impl WitnessCommitment
pub const fn from_byte_array(bytes: [u8; 32]) -> Self
pub const fn from_byte_array(bytes: [u8; 32]) -> Self
Constructs a new type from the underlying byte array.
pub const fn to_byte_array(self) -> [u8; 32]
pub const fn to_byte_array(self) -> [u8; 32]
Returns the underlying byte array.
pub const fn as_byte_array(&self) -> &[u8; 32]
pub const fn as_byte_array(&self) -> &[u8; 32]
Returns a reference to the underlying byte array.