pub struct Version(/* private fields */);Expand description
The transaction version.
Currently, as specified by BIP-0068 and BIP-0431, version 1, 2, and 3 are considered standard.
Standardness of the inner u32 is not an invariant because you are free to create transactions
of any version, transactions with non-standard version numbers will not be relayed by the
Bitcoin network.
Implementations
Sourceimpl Version
impl Version
Sourcepub const fn maybe_non_standard(version: u32) -> Self
pub const fn maybe_non_standard(version: u32) -> Self
Constructs a potentially non-standard transaction version.
This can accept both standard and non-standard versions.
Sourcepub const fn is_standard(self) -> bool
pub const fn is_standard(self) -> bool
Returns true if this transaction version number is considered standard.
The behavior of this method matches whatever Bitcoin Core considers standard at the time of the release and may change in future versions to accommodate new standard versions. As of Bitcoin Core 28.0 (release notes), versions 1, 2, and 3 are considered standard.