Error types for bitcoin amounts.
Structs
- Amount
Decoder Error - An error consensus decoding an
Amount. - BadPosition
Error - Error returned when a valid character (e.g. ‘_’) is in an invalid/bad position.
- Input
TooLarge Error - Error returned when the input string is too large.
- Invalid
Character Error - Error returned when the input contains an invalid character.
- Missing
Denomination Error - Error returned when the denomination is empty.
- Missing
Digits Error - Error returned when digits were expected in the input but there were none.
- OutOf
Range Error - Error returned when a parsed amount is too big or too small.
- Parse
Amount Error - Error returned when parsing an amount fails.
- Parse
Error - Error returned when parsing an amount with denomination fails.
- Possibly
Confusing Denomination Error - Error returned when parsing a possibly confusing denomination.
- TooPrecise
Error - Error returned when the input string has higher precision than satoshis.
- Unknown
Denomination Error - Error returned when parsing an unknown denomination.
Enums
- Parse
Denomination Error - An error during amount parsing.