Parsing utilities.
Re-exports
pub use parse_int::ParseIntError;pub use parse_int::PrefixedHexError;pub use parse_int::UnprefixedHexError;
Modules
- error
- Error types for integer parsing utilities.
Traits
- Integer
- Not strictly necessary but serves as a lint - avoids weird behavior if someone accidentally
passes non-integer to the
parse()function.
Functions
- hex_
check_ unprefixed - Checks a hex string does not have a prefix
0x(or0X). - hex_
remove_ prefix - Removes the prefix
0x(or0X) from a hex string. - hex_u16
- Parses a
u16from a hex string. - hex_u32
- Parses a
u32from a hex string. - hex_u64
- Parses a
u64from a hex string. - hex_
u16_ prefixed - Parses a
u16from a prefixed hex string. - hex_
u16_ unprefixed - Parses a
u16from an unprefixed hex string. - hex_
u32_ prefixed - Parses a
u32from a prefixed hex string. - hex_
u32_ unprefixed - Parses a
u32from an unprefixed hex string. - hex_
u64_ prefixed - Parses a
u64from a prefixed hex string. - hex_
u64_ unprefixed - Parses a
u64from an unprefixed hex string. - hex_
u128 - Parses a
u128from a hex string. - hex_
u128_ prefixed - Parses a
u128from a prefixed hex string. - hex_
u128_ unprefixed - Parses a
u128from an unprefixed hex string. - int_
from_ box - Parses the input string as an integer returning an error carrying rich context.
- int_
from_ str - Parses the input string as an integer returning an error carrying rich context.
- int_
from_ string - Parses the input string as an integer returning an error carrying rich context.