pub fn int_from_string<T>(s: String) -> Result<T, ParseIntError>where
T: Integer,Expand description
Parses the input string as an integer returning an error carrying rich context.
Errors
On error the input string is moved into the error return without allocating.