Module script

Module script 

Bitcoin scripts.

Re-exports

pub use self::error::PushBytesError;
pub use self::error::RedeemScriptSizeError;
pub use self::error::ScriptBufDecoderError;
pub use self::error::WitnessScriptSizeError;

Modules

error
Error types for Bitcoin scripts.

Structs

Builder
An Object which can be used to construct a script piece by piece.
PushBytes
Byte slices that can be in Bitcoin script.
PushBytesBuf
Owned, growable counterpart to PushBytes.
Script
Bitcoin script slice.
ScriptBuf
An owned, growable script.
ScriptBufDecoder
The decoder for the ScriptBuf type.
ScriptEncoder
The encoder for the Script<T> type.
ScriptHash
A 160-bit hash of Bitcoin Script bytecode.
WScriptHash
SegWit (256-bit) version of a Bitcoin Script bytecode hash.

Enums

RedeemScriptTag
A P2SH redeem script.
ScriptPubKeyTag
A script public key (scriptPubKey).
ScriptSigTag
A script signature (scriptSig).
SignetBlockScriptTag
A signet block challenge script.
TapScriptTag
A Segwit v1 Taproot script.
WitnessScriptTag
A Segwit v0 witness script.

Constants

MAX_REDEEM_SCRIPT_SIZE
The maximum allowed redeem script size for a P2SH output.
MAX_WITNESS_SCRIPT_SIZE
The maximum allowed redeem script size of the witness script.

Traits

PushBytesErrorReport
Reports information about failed conversion into PushBytes.
ScriptHashableTag
Either a redeem script or a Segwit version 0 scriptpubkey.
Tag
Sealed trait representing a type of script.

Type Aliases

RedeemScript
A reference to a P2SH redeem script.
RedeemScriptBuf
A P2SH redeem script.
ScriptPubKey
A reference to a scriptPubKey (locking script).
ScriptPubKeyBuf
A scriptPubKey (locking script).
ScriptPubKeyBufDecoder
A scriptPubKey decoder.
ScriptSig
A reference to a script signature (scriptSig).
ScriptSigBuf
A script signature (scriptSig).
ScriptSigBufDecoder
A scriptSig decoder.
SignetBlockScript
A reference to a signet block/challenge script.
SignetBlockScriptBuf
A signet block/challenge script.
TapScript
A reference to a Segwit v1 Taproot script.
TapScriptBuf
A Segwit v1 Taproot script.
WitnessScript
A reference to a Segwit v0 witness script.
WitnessScriptBuf
A Segwit v0 witness script.