Module script

Module script 

Bitcoin scripts.

Structs

RedeemScriptSizeError
Error while hashing a redeem script.
Script
Bitcoin script slice.
ScriptBuf
An owned, growable script.
ScriptBufDecoder
The decoder for the ScriptBuf type.
ScriptBufDecoderError
An error consensus decoding a ScriptBuf<T>.
ScriptEncoder
The encoder for the Script<T> type.
ScriptHash
A 160-bit hash of Bitcoin Script bytecode.
WScriptHash
SegWit (256-bit) version of a Bitcoin Script bytecode hash.
WitnessScriptSizeError
Error while hashing a witness script.

Enums

RedeemScriptTag
A P2SH redeem script.
ScriptPubKeyTag
A script public key (scriptPubKey).
ScriptSigTag
A script signature (scriptSig).
TapScriptTag
A Segwit v1 Taproot script.
WitnessScriptTag
A Segwit v0 witness script.

Constants

MAX_REDEEM_SCRIPT_SIZE
The maximum allowed redeem script size for a P2SH output.
MAX_WITNESS_SCRIPT_SIZE
The maximum allowed redeem script size of the witness script.

Traits

ScriptHashableTag
Either a redeem script or a Segwit version 0 scriptpubkey.
Tag
Sealed trait representing a type of script.

Type Aliases

RedeemScript
A reference to a P2SH redeem script.
RedeemScriptBuf
A P2SH redeem script.
ScriptPubKey
A reference to a scriptPubKey (locking script).
ScriptPubKeyBuf
A scriptPubKey (locking script).
ScriptPubKeyBufDecoder
A scriptPubKey decoder.
ScriptSig
A reference to a script signature (scriptSig).
ScriptSigBuf
A script signature (scriptSig).
ScriptSigBufDecoder
A scriptSig decoder.
TapScript
A reference to a Segwit v1 Taproot script.
TapScriptBuf
A Segwit v1 Taproot script.
WitnessScript
A reference to a Segwit v0 witness script.
WitnessScriptBuf
A Segwit v0 witness script.