Bitcoin scripts.
Structs
- Redeem
Script Size Error - Error while hashing a redeem script.
- Script
- Bitcoin script slice.
- Script
Buf - An owned, growable script.
- Script
BufDecoder - The decoder for the
ScriptBuftype. - Script
BufDecoder Error - An error consensus decoding a
ScriptBuf<T>. - Script
Encoder - The encoder for the
Script<T>type. - Script
Hash - A 160-bit hash of Bitcoin Script bytecode.
- WScript
Hash - SegWit (256-bit) version of a Bitcoin Script bytecode hash.
- Witness
Script Size Error - Error while hashing a witness script.
Enums
- Redeem
Script Tag - A P2SH redeem script.
- Script
PubKey Tag - A script public key (scriptPubKey).
- Script
SigTag - A script signature (scriptSig).
- TapScript
Tag - A Segwit v1 Taproot script.
- Witness
Script Tag - A Segwit v0 witness script.
Constants
- MAX_
REDEEM_ SCRIPT_ SIZE - The maximum allowed redeem script size for a P2SH output.
- MAX_
WITNESS_ SCRIPT_ SIZE - The maximum allowed redeem script size of the witness script.
Traits
- Script
Hashable Tag - Either a redeem script or a Segwit version 0 scriptpubkey.
- Tag
- Sealed trait representing a type of script.
Type Aliases
- Redeem
Script - A reference to a P2SH redeem script.
- Redeem
Script Buf - A P2SH redeem script.
- Script
PubKey - A reference to a
scriptPubKey(locking script). - Script
PubKey Buf - A
scriptPubKey(locking script). - Script
PubKey BufDecoder - A
scriptPubKeydecoder. - Script
Sig - A reference to a script signature (scriptSig).
- Script
SigBuf - A script signature (scriptSig).
- Script
SigBuf Decoder - A
scriptSigdecoder. - TapScript
- A reference to a Segwit v1 Taproot script.
- TapScript
Buf - A Segwit v1 Taproot script.
- Witness
Script - A reference to a Segwit v0 witness script.
- Witness
Script Buf - A Segwit v0 witness script.