pub struct ScriptBuf<T>(/* private fields */);Expand description
An owned, growable script.
ScriptBuf is the most common script type that has the ownership over the contents of the
script. It has a close relationship with its borrowed counterpart, Script.
Just as other similar types, this implements Deref, so deref coercions apply. Also note
that all the safety/validity restrictions that apply to Script apply to ScriptBuf as well.
Hexadecimal strings
Scripts are consensus encoded with a length prefix and as a result of this in some places in the
ecosystem one will encounter hex strings that include the prefix while in other places the
prefix is excluded. To support parsing and formatting scripts as hex we provide a bunch of
different APIs and trait implementations. Please see examples/script.rs for a thorough
example of all the APIs.
Panics
ScriptBuf is backed by Vec and inherits its panic behavior. This means that attempting to
construct scripts larger than isize::MAX bytes will panic.
Implementations
Sourceimpl<T> ScriptBuf<T>
impl<T> ScriptBuf<T>
Sourcepub const fn from_bytes(bytes: Vec<u8>) -> Self
pub const fn from_bytes(bytes: Vec<u8>) -> Self
Converts byte vector into script.
This method doesn’t (re)allocate. bytes is just the script bytes not consensus
encoding (i.e no length prefix).
Sourcepub fn as_mut_script(&mut self) -> &mut Script<T>
pub fn as_mut_script(&mut self) -> &mut Script<T>
Returns a mutable reference to unsized script.
Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Converts the script into a byte vector.
This method doesn’t (re)allocate.
Returns
Just the script bytes not consensus encoding (which includes a length prefix).
Sourcepub fn into_boxed_script(self) -> Box<Script<T>>
pub fn into_boxed_script(self) -> Box<Script<T>>
Converts this ScriptBuf into a boxed Script.
This method reallocates if the capacity is greater than length of the script but should not
when they are equal. If you know beforehand that you need to create a script of exact size
use reserve_exact before adding data to the script so that the
reallocation can be avoided.
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Constructs a new empty script with at least the specified capacity.
Sourcepub fn reserve(&mut self, additional_len: usize)
pub fn reserve(&mut self, additional_len: usize)
Pre-allocates at least additional_len bytes if needed.
Reserves capacity for at least additional_len more bytes to be inserted in the given
script. The script may reserve more space to speculatively avoid frequent reallocations.
After calling reserve, capacity will be greater than or equal to
self.len() + additional_len. Does nothing if capacity is already sufficient.
Panics
Panics if the new capacity exceeds isize::MAX bytes.
Sourcepub fn reserve_exact(&mut self, additional_len: usize)
pub fn reserve_exact(&mut self, additional_len: usize)
Pre-allocates exactly additional_len bytes if needed.
Unlike reserve, this will not deliberately over-allocate to speculatively avoid frequent
allocations. After calling reserve_exact, capacity will be greater than or equal to
self.len() + additional. Does nothing if the capacity is already sufficient.
Note that the allocator may give the collection more space than it requests. Therefore,
capacity cannot be relied upon to be precisely minimal. Prefer reserve
if future insertions are expected.
Panics
Panics if the new capacity exceeds isize::MAX bytes.
Methods from Deref<Target = Script<T>>
Sourcepub fn as_bytes(&self) -> &[u8] ⓘ
pub fn as_bytes(&self) -> &[u8] ⓘ
Returns the script data as a byte slice.
This is just the script bytes not consensus encoding (which includes a length prefix).
Sourcepub fn as_mut_bytes(&mut self) -> &mut [u8] ⓘ
pub fn as_mut_bytes(&mut self) -> &mut [u8] ⓘ
Returns the script data as a mutable byte slice.
This is just the script bytes not consensus encoding (which includes a length prefix).
Sourcepub fn to_vec(&self) -> Vec<u8> ⓘ
pub fn to_vec(&self) -> Vec<u8> ⓘ
Returns a copy of the script data.
This is just the script bytes not consensus encoding (which includes a length prefix).