pub struct ScriptHash(/* private fields */);Expand description
A 160-bit hash of Bitcoin Script bytecode.
Note: there is another “script hash” object in bitcoin ecosystem (Electrum protocol) that uses 256-bit hash and hashes a semantically different script. Thus, this type cannot represent it.
Implementations
Sourceimpl ScriptHash
impl ScriptHash
Sourcepub fn from_script<T>(
redeem_script: &Script<T>,
) -> Result<Self, RedeemScriptSizeError>where
T: ScriptHashableTag,
pub fn from_script<T>(
redeem_script: &Script<T>,
) -> Result<Self, RedeemScriptSizeError>where
T: ScriptHashableTag,
Constructs a new ScriptHash after first checking the script size.
520-byte limitation on serialized script size
As a consequence of the requirement for backwards compatibility the serialized script is itself subject to the same rules as any other PUSHDATA operation, including the rule that no data greater than 520 bytes may be pushed to the stack. Thus it is not possible to spend a P2SH output if the redemption script it refers to is >520 bytes in length.
ref: BIP-0016
Errors
Returns an error if the script exceeds 520 bytes.
Sourcepub fn from_script_unchecked<T>(script: &Script<T>) -> Self
pub fn from_script_unchecked<T>(script: &Script<T>) -> Self
Constructs a new ScriptHash from any script irrespective of script size.
If you hash a script that exceeds 520 bytes in size and use it to create a P2SH output then the output will be unspendable (see BIP-0016).
impl ScriptHash
impl ScriptHash
pub const fn from_byte_array(bytes: [u8; 20]) -> Self
pub const fn from_byte_array(bytes: [u8; 20]) -> Self
Constructs a new type from the underlying byte array.
pub const fn to_byte_array(self) -> [u8; 20]
pub const fn to_byte_array(self) -> [u8; 20]
Returns the underlying byte array.
pub const fn as_byte_array(&self) -> &[u8; 20]
pub const fn as_byte_array(&self) -> &[u8; 20]
Returns a reference to the underlying byte array.