BlockMtp

Struct BlockMtp 

pub struct BlockMtp(/* private fields */);
The median timestamp of 11 consecutive blocks.

This type is not meant for constructing time-based timelocks. It is a general purpose MTP abstraction. For locktimes please see [locktime::absolute::MedianTimePast].

This is a thin wrapper around a u32 that may take on all values of a u32.

Implementations

Source

impl BlockMtp

pub fn from_hex(s: &str) -> Result<BlockMtp, PrefixedHexError>

Constructs a new BlockMtp from an unprefixed hex string.

Errors

If the input string is not a valid hex representation of a BlockMtp or it does not include the 0x prefix.

pub fn from_unprefixed_hex(s: &str) -> Result<BlockMtp, UnprefixedHexError>

Constructs a new BlockMtp from a prefixed hex string.

Errors

If the input string is not a valid hex representation of a BlockMtp or if it includes the 0x prefix.

Source

impl BlockMtp

pub const ZERO: BlockMtp

Block MTP 0.

Since MTP is a timestamp, 0 is before Bitcoin was invented. This const may still be useful for some use cases e.g., folding a sum of intervals.

pub const MIN: BlockMtp = Self::ZERO

The minimum block MTP, equivalent to Self::ZERO.

pub const MAX: BlockMtp

The maximum block MTP.

pub const fn from_u32(inner: u32) -> BlockMtp

Constructs a new block MTP from a u32.

pub const fn to_u32(self) -> u32

Returns block MTP as a u32.

pub fn new(timestamps: [BlockTime; 11]) -> BlockMtp

Constructs a BlockMtp by computing the median‐time‐past from the last 11 block timestamps

Because block timestamps are not monotonic, this function internally sorts them; it is therefore not important what order they appear in the array; use whatever is most convenient.

pub fn checked_sub(self, other: BlockMtp) -> Option<BlockMtpInterval>

Attempt to subtract two BlockMtps, returning None if overflow occurred.

pub fn checked_add(self, other: BlockMtpInterval) -> Option<BlockMtp>

Attempt to add an interval to this BlockMtp, returning None if overflow occurred.