TxOut

Struct TxOut 

pub struct TxOut {
    pub amount: Amount,
    pub script_pubkey: ScriptPubKeyBuf,
}
Bitcoin transaction output.

Defines new coins to be created as a result of the transaction, along with spending conditions (“script”, aka “output script”), which an input spending it must satisfy.

An output that is not yet spent by an input is called Unspent Transaction Output (“UTXO”).

Bitcoin Core References

Fields

amount: Amount

The value of the output.

script_pubkey: ScriptPubKeyBuf

The script which must be satisfied for the output to be spent.